@@ -5,12 +5,9 @@
 from __future__ import (absolute_import, division, generators, nested_scopes, print_function,
                         unicode_literals, with_statement)
 
-import os
-
 from pants.backend.jvm.tasks.jvm_compile.zinc.zinc_compile import BaseZincCompile
-from pants.util.memo import memoized_property
+from pants.util.memo import memoized_method
 
-from pants.contrib.scalajs.subsystems.scala_js_platform import ScalaJSPlatform
 from pants.contrib.scalajs.targets.scala_js_target import ScalaJSTarget
 
 
@@ -20,6 +17,8 @@ class ScalaJSZincCompile(BaseZincCompile):
   _name = 'scala-js'
   _file_suffix = '.scala'
 
+  scalac_plugins = ['scalajs']
+
   @classmethod
   def register_options(cls, register):
     super(ScalaJSZincCompile, cls).register_options(register)
@@ -30,15 +29,10 @@ class ScalaJSZincCompile(BaseZincCompile):
   def product_types(cls):
     return ['scala_js_ir']
 
-  @memoized_property
-  def plugin_jars(self):
+  @memoized_method
+  def scalac_plugin_classpath_elements(self):
     return self.tool_classpath('scala-js-compiler')
 
-  @memoized_property
-  def plugin_args(self):
-    # filter the tool classpath to select only the compiler jar
-    return ['-S-Xplugin:{}'.format(jar) for jar in self.plugin_jars if 'scalajs-compiler_' in jar]
-
   def select(self, target):
     if not isinstance(target, ScalaJSTarget):
       return False
